tupelo - Making Clojure even sweeter
tupelo - Making Clojure even sweeter
(put-go! ch val)Puts a value onto a channel. Only valid in a go block.
Will park if channel is full. Equivalent to clojure.core.async/>!
Puts a value onto a channel. Only valid in a `go` block. Will park if channel is full. Equivalent to clojure.core.async/>!
(put-later! port val & args)Puts a value onto a channel from another thread.
Equivalent to clojure.core.async/put!
Puts a value onto a channel from another thread. Equivalent to `clojure.core.async/put!`
(put-now! ch val)Puts a value onto a channel.
Will block if channel is full. Equivalent to clojure.core.async/<!!
Puts a value onto a channel. Will block if channel is full. Equivalent to `clojure.core.async/<!!`
(take-go! ch)Takes a value from a channel and returns it. Only valid in a go block.
Will park if no value is available. Equivalent to clojure.core.async/<!
Takes a value from a channel and returns it. Only valid in a `go` block. Will park if no value is available. Equivalent to clojure.core.async/<!
(take-later! & args)Takes a value from a channel & passes it to the supplied function, using another thread.
Equivalent to clojure.core.async/take!
Takes a value from a channel & passes it to the supplied function, using another thread. Equivalent to `clojure.core.async/take!`
(take-now! ch)Takes a value from a channel and returns it.
Will block if no value is available. Equivalent to clojure.core.async/<!!
Takes a value from a channel and returns it. Will block if no value is available. Equivalent to `clojure.core.async/<!!`
(vec ch)Extract all values from a channel into a vector.
Extract all values from a channel into a vector.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |